using Autofac;
using FitConnect;
using FitConnect.Interfaces.Sender;
using FitConnect.Interfaces.Subscriber;
using FitConnect.Models;
using Microsoft.Extensions.Logging;
using MockContainer;

namespace E2ETest;

public abstract class EndToEndTestBase {
    private ISender _sender;
    private ISubscriber _subscriber;

    [OneTimeSetUp]
    public void Setup() {
        var container = MockContainer.Container.Create();
        var settings = container.Resolve<MockSettings>();

        var logger = LoggerFactory.Create(
            builder => {
                builder.AddSimpleConsole();
                builder.SetMinimumLevel(LogLevel.Trace);
            }).CreateLogger("E2E Test");


        _sender = Client.GetSender(FitConnectEnvironment.Development,
            settings.SenderClientId, settings.SenderClientSecret,
            logger);
        _subscriber = Client.GetSubscriber(FitConnectEnvironment.Development,
            settings.SenderClientId, settings.SenderClientSecret,
            settings.PrivateKeyDecryption,
            settings.PrivateKeySigning,
            settings.PublicKeyEncryption,
            settings.PublicKeySignatureVerification,
            logger
        );
    }
}
